==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl<LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBUseSourceIp,LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder>{
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBUseSourceIp(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBUseSourceIp(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent,LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent,LoadBalancerSettingsConsistentHashLBUseSourceIp instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withUseSourceIp(instance.getUseSourceIp());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIp instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withUseSourceIp(instance.getUseSourceIp());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBUseSourceIp build() {
    LoadBalancerSettingsConsistentHashLBUseSourceIp buildable = new LoadBalancerSettingsConsistentHashLBUseSourceIp(fluent.getUseSourceIp());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBUseSourceIp,LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder>{
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBUseSourceIp(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBUseSourceIp(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent,LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent,LoadBalancerSettingsConsistentHashLBUseSourceIp instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBUseSourceIp());

    if (instance != null) {
      fluent.withUseSourceIp(instance.getUseSourceIp());
      fluent.withUseSourceIp(instance.getUseSourceIp());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(LoadBalancerSettingsConsistentHashLBUseSourceIp instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBUseSourceIp());

    if (instance != null) {
      this.withUseSourceIp(instance.getUseSourceIp());
      this.withUseSourceIp(instance.getUseSourceIp());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBUseSourceIp build() {
    LoadBalancerSettingsConsistentHashLBUseSourceIp buildable = new LoadBalancerSettingsConsistentHashLBUseSourceIp(fluent.getUseSourceIp());
    return buildable;
  }
  
}
